@@ -9,13 +9,18 @@
 #pragma once
 
 #include <KContacts/Addressee>
-
-#include <editor/widgets/categorieseditabstractwidget.h>
+#include <KJob>
+#include <QVariant>
+#include <QWidget>
+namespace Akonadi
+{
+class TagWidget;
+}
 
 /**
  * @short A widget for editing the categories of a contact.
  */
-class CategoriesEditWidget : public ContactEditor::CategoriesEditAbstractWidget
+class CategoriesEditWidget : public QWidget
 {
     Q_OBJECT
 
@@ -23,8 +28,12 @@ public:
     explicit CategoriesEditWidget(QWidget *parent = nullptr);
     ~CategoriesEditWidget() override;
 
-    void loadContact(const KContacts::Addressee &contact) override;
-    void storeContact(KContacts::Addressee &contact) const override;
+    void loadContact(const KContacts::Addressee &contact);
+    void storeContact(KContacts::Addressee &contact) const;
 
-    void setReadOnly(bool readOnly) override;
+    void setReadOnly(bool readOnly);
+
+private:
+    void onMissingTagCreated(KJob *);
+    Akonadi::TagWidget *const mTagWidget;
 };
